@@ -7,7 +7,7 @@ use DBIx::Class::ResultClass::HashRefInflator;
 use DBIx::Class::ResultSet::RecursiveUpdate;
 use Scalar::Util ('blessed');
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =head1 NAME
 
@@ -400,10 +400,36 @@ sub validate_unique
    @id_clause = _id_clause( $rs, $self->item_id ) if defined $self->item;
    
    my $value = $self->value;
+   for my $field ( @$fields )
+   {
+      next unless $field->unique;
+      next if $field->has_errors;
+      my $value = $field->value;
+      next unless defined $value;
+      my $accessor   = $field->accessor;
+
+      my $count = $rs->search( { $accessor => $value, @id_clause } )->count;
+      next if $count < 1;
+      my $field_error = $field->unique_message || 'Duplicate value for ' . $field->label;
+      $field->add_error( $field_error );
+      $found_error++;
+   }
+
    # validate unique constraints in the model
    for my $constraint (@{ $self->unique_constraints })
    {
       my @columns = $rs->result_source->unique_constraint_columns($constraint);
+
+      # check for matching field in the form 
+      my $field;
+      for my $col (@columns)
+      {
+         ($field) = grep { $_->accessor eq $col } @$fields;
+         last if $field;
+      }
+      next unless defined $field;
+      next if ( $field->has_unique ); # already handled or don't do
+
       my @values = map {
          exists( $value->{$_} ) ? $value->{$_} : undef
             ||
@@ -418,38 +444,11 @@ sub validate_unique
       my $count = $rs->search( \%where )->search({@id_clause})->count;
       next if $count < 1;
 
-      # now find the field we can attach the error to
-      my $field;
-      for my $col (@columns)
-      {
-         ($field) = grep { $_->accessor eq $col } @$fields;
-         last if $field;
-      }
-      next unless defined $field;
-      # the check for fields that do *not* want a unique check should be done
-      # earlier, but this is the simplest place
-      next if ( $field->has_unique && $field->unique == 0 );
-
       my $field_error = $self->unique_message_for_constraint($constraint);
       $field->add_error( $field_error );
       $found_error++;
    }
 
-   for my $field ( @$fields )
-   {
-      next unless $field->unique;
-      next if $field->has_errors;
-      my $value = $field->value;
-      next unless defined $value;
-      my $accessor   = $field->accessor;
-
-      my $count = $rs->search( { $accessor => $value, @id_clause } )->count;
-      next if $count < 1;
-      my $field_error = $field->unique_message || 'Duplicate value for ' . $field->label;
-      $field->add_error( $field_error );
-      $found_error++;
-   }
-
    return $found_error;
 }
 
